@@ -1,6 +1,6 @@
 from judgeval.judges.base_judge import JudgevalJudge
 from judgeval.judges.litellm_judge import LiteLLMJudge
 from judgeval.judges.together_judge import TogetherJudge
-from judgeval.judges.mixture_of_judges import MixtureOfJudges
 
-__all__ = ["JudgevalJudge", "LiteLLMJudge", "TogetherJudge", "MixtureOfJudges"]
+
+__all__ = ["JudgevalJudge", "LiteLLMJudge", "TogetherJudge"]
