@@ -2,8 +2,10 @@ import importlib.metadata
 import httpx
 import threading
 from judgeval.logger import judgeval_logger
+from judgeval.utils.decorators import use_once
 
 
+@use_once
 def check_latest_version(package_name: str = "judgeval"):
     def _check():
         try:
